# This is the sample configuration file for VMM Express. All the paremeters should be
# modified according to your setup for correct deployment of VMM Express.

# Start VMMExpress.ps1: 
# .\VMMExpress.ps1 -ConfigurationDataFile .\Fabricconfig-SDNcloud-Production.psd1

# If during uninstall of NC a network adapter is locked, try following commands:
#  Get-SCVMHostNetworkAdapter -VMHost SDN-HV01 | ?{$_.UplinkPortProfileSet -ne $null} | Set-SCVMHostNetworkAdapter -RemoveUplinkPortProfileSet -Verbose 
#  Get-SCVMHostNetworkAdapter -VMHost SDN-HV02 | ?{$_.UplinkPortProfileSet -ne $null} | Set-SCVMHostNetworkAdapter -RemoveUplinkPortProfileSet -Verbose 

@{

    AllNodes = 
    @(
        @{ 
            
							
            ###########################
            #  VM Creation variables  #
            ###########################
            
            # Name of the VHD or VHDX to use for VM creation. Must Exist in the
            # VMM Library            
            VHDName="WS2016_EN.vhdx"
            
            # VMM Library share to be used for keeping the resources.
            VMMLibrary="\\SDN-VMM01\MSSCVMMLibrary"
            
            # Product key Can be blank if using a volume license VHD or VHDX, or you are
            # deploying in eval mode.  (Don't forget to press "skip" while VM creation).
            ProductKey="TMJ3Y-NTRTM-FJYXT-T22BY-CWG3J" 

            #Generation of VM to be used for deployment : Gen1 or Gen2
            Generation="Gen2"

            #Type of Deployment. The values are :
            #Standalone : For single Node 
            #Production : For 3-node
            DeploymentType="Production"	
			
			#Higly Available VM. Do you want the infrastructural VMs to be deployed on
			#Clustered Host and being higly Available ? If yes pass $true else $false
			HighlyAvailableVMs = $true
            
            StorageClassification = "Remote Storage"

            #leave it if you want default IPvAddressType to be taken which is static
            # else change it to "Dynamic"
            IPv4AddressType=""
                        
            #Host Group to be Managed by Network Controller
            NCHostGroupName="SDN-Hosts"
            
            #########################################################################
            #  Section to be filled if the Logical switch and Logical Network       #
            #  is already deployed for NC. You should do this if SET ( teamed)      #
            #  support is required. If you want VMM express to deploy the Logical   #
            #  switch and Management Network, skip this section.                    # 
            #  NOTE : This script assumes either you have both logical switch and   #
            # logical Network created and deployed or else you will use the script  #
            # to deploy both.                                                       #
            #########################################################################
            
            #Do you have an existing logical switch and the switch is deployed on all
            #the host you wish to Manage by NC
            # IsLogicalSwitchDeployed = $false
            IsLogicalSwitchDeployed = $true
            
            #if above is true give the name of logical switch			
            LogicalSwitch  = "NC_LogicalSwitch"

            # Do you have existing Management Network that you would like to use
            # IsManagementVMNetworkExisting = $false
            IsManagementVMNetworkExisting = $true

            #if above is true give the name of ManagementVMNetwork
            ManagementVMNetwork = "NC_Management" 

            #Uplink Port Profile to be used
            UplinkPortProfile = "HV Uplink Port"            
             
            #====================================================================================
            # The below set of Parameters are required for creation of Management Logical Network
            # and other Logical Networks Managed by NC.                                           
            # NOTE : If you already have Management Logical Network Created and switch deployed,
            # you don't need to specify any paramenet for "NC_Management" LN
            #====================================================================================
             LogicalNetworks = @(
			    @{
                    Name = "HNVPA"
                    Subnets = @(
                        @{
                            # VLANID = 255                                           #Example: 11
                            VLANID = 0                                             #Example: 11
                            AddressPrefix = "10.10.10.0/24"                        #Example: "10.0.10.0/24"
                            DNS = @("192.168.80.10")                               #Example: @("10.0.0.7", "10.0.0.8", "10.0.0.9")
                            Gateways = "10.10.10.1"                                #Example: "10.0.10.1"
                            PoolStart = "10.10.10.100"                             #Example: "10.0.10.50"
                            PoolEnd = "10.10.10.199"                               #Example: "10.0.10.150"
                       }
                    )
                },
				@{
                    Name = "Transit"
                    Subnets = @(
                        @{
                            # VLANID = 254                                           #Example: 12
                            VLANID = 0                                             #Example: 12
                            AddressPrefix = "10.10.20.0/24"                        #Example: "10.0.40.0/24"
                            DNS = @("192.168.80.10")                               #Example: @("10.0.0.7", "10.0.0.8", "10.0.0.9")
                            Gateways = "10.10.20.1"                                #Example: "10.0.40.1"
                            PoolStart = "10.10.20.100"                              #Example: "10.0.40.5"
                            PoolEnd = "10.10.20.199"                                #Example: "10.0.40.100"
                        }  
                    )
                }, 
                @{
                    #The first IP address (PoolStart) for this logical network is 
                    #automatically assigned to the SLB Manager.Other addresses such
                    #as the GatewayPublicIPAddress will start after that.
                    Name = "PublicVIP"
                    Subnets = @(
                        @{
                            VLANID = 0
                            AddressPrefix = "10.10.50.0/24"                       #Example: "10.0.20.0/24"
                            DNS = @("192.168.80.10")                              #Example: @("10.0.0.7", "10.0.0.8", "10.0.0.9")
                            Gateways = "10.10.50.1"                               #Example: "10.0.20.1"
                            PoolStart = "10.10.50.100"                            #Example: "10.0.20.5"
                            PoolEnd = "10.10.50.199"                              #Example: "10.0.20.100"
                            IsPublic = $true
                        }  
                    )
                },
                @{
                    #The first IP address (PoolStart) for this logical network is 
                    #automatically assigned to the SLB Manager.Other addresses such
                    #as the GatewayPublicIPAddress will start after that.
                    Name = "PrivateVIP"
                    Subnets = @(
                        @{
                            # VLANID = 253
                            VLANID = 0
                            AddressPrefix = "10.10.30.0/24"                         #Example: "10.0.20.0/24"
                            DNS = @("192.168.80.10")                                  #Example: @("10.0.0.7", "10.0.0.8", "10.0.0.9")
                            Gateways = "10.10.30.1"                                #Example: "10.0.20.1"
                            PoolStart = "10.10.30.100"                               #Example: "10.0.20.5"
                            PoolEnd = "10.10.30.199"                                 #Example: "10.0.20.100"
                            IsPublic = $false
                        }  
                    )
                },
                @{
                    #This is used for onboarding Gateway
                    Name = "GREVIP"                                # Don't change this. There should be no LN with this name in VMM
                    Subnets = @(
                        @{
                            VLANID = 0
                            AddressPrefix = "10.10.40.0/24"                         #Example: "10.0.20.0/24"
                            DNS = @("192.168.80.10")                                #Example: @("10.0.0.7", "10.0.0.8", "10.0.0.9")
                            Gateways = "10.10.40.1"                              #Example: "10.0.20.1"
                            PoolStart = "10.10.40.100"                             #Example: "10.0.20.5"
                            PoolEnd = "10.10.40.199"                               #Example: "10.0.20.100"
                            IsPublic = $false
                        }  
                    )
                }				
                @{
				    #if Management VM Network is not deployed give the ManagementVMNetwork information. Skip
                    # this if you already have this created.
                    Name = "NC_Management"
                    Subnets = @(
                        @{
                            # VLANID = 811                                            #Example: 7
                            VLANID = 0                                            #Example: 7
                            AddressPrefix = "192.168.80.0/24"                       #Example: "10.0.0.0/24"
                            DNS = @("192.168.80.10")                                #Example: @("10.0.0.7", "10.0.0.8", "10.0.0.9")
                            Gateways = "192.168.80.1"                               #Example: "10.0.40.1"
                            PoolStart = "192.168.80.230"                            #Example: "10.0.0.5"
                            PoolEnd = "192.168.80.254"                              #Example: "10.0.0.100"
                            ReservedIPset =  "192.168.80.230"                       #This IP will be used for NC Rest API                           
                        }  
                    )
                }
            )
								
            #=========================================================================================
            # The following set of paremeters are required for importing VMM service Template,
            # configuring the Service Template and Deploying the service Template.
            #==========================================================================================

            # Make this true if self signed certificate is to be used
            # Example : $True , $False
            IsCertSelfSigned = $true  

            #The password for server certificate. This sertificate will be installed on the Host
            ServerCertificatePassword="Passw0rd!"	            

            # The following are service settings required for configuring and
            # deploying the service template imported client security Group Name
            ClientSecurityGroupName= "SDNcloud\Network Controller Users"

            # Local Admin credentials
            # The local admin user name will be .\Administrator
            LocalAdminPassword= "Passw0rd!"    

            # Management Domain Account Which will be used for NC Deployment
            ManagementDomainUser="SDNcloud\FabAdmin"
            ManagementDomainUserPassword="Passw0rd!"

             # This is the domain which NC VMs will join
            ManagementDomainFDQN="SDNcloud.local"		

            #Managemet Security Group Name
            ManagementSecurityGroupName="SDNcloud\Network Controller Admins"
            
            # Prefix to be added to infrastructural VMs created. Put the prefix such
            # that it makes VM name unique as this is the machine name of VM and should be unique.            
            ComputerNamePrefix = "SDN"   

            # RestName = "SDN-NCREST.SDNcloud.local"
            RestName = "192.168.80.230"
            
            ##################################
            #  Deoloyment Control Switches   #
            ##################################
                                    
            # Do you want to deploy NC
            # DeployNC = $true
            DeployNC = $False
            
			#Do you want to create NC managed HNVPA, Transit networks. This are required if SLB and GW needs to be deployed
            # createNCManagedNetworks = $true
            createNCManagedNetworks = $false

            #Do you want to Deploy SLB. Values are $true , $false
            DeploySLB =   $false
            # DeploySLB =   $true

            #Do you want to deploy GW. Values are $true , $false
            DeployGW = $true
            # DeployGW = $false
        };
           
     );
}
